==> pierogi_1.1.29.tar.gz: pierogi-1.1.29/keysets/universum.h <==
//
// universum.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef UNIVERSUM_H
#define UNIVERSUM_H

#include "pirkeysetmetadata.h"

class QObject;

class UniversumVCR1: public PIRKeysetMetaData
{
public:
  UniversumVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumVCR2: public PIRKeysetMetaData
{
public:
  UniversumVCR2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumVCR3: public PIRKeysetMetaData
{
public:
  UniversumVCR3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumTV1: public PIRKeysetMetaData
{
public:
  UniversumTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumTV1a: public UniversumTV1
{
public:
  UniversumTV1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumSat1: public PIRKeysetMetaData
{
public:
  UniversumSat1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumAudio1: public PIRKeysetMetaData
{
public:
  UniversumAudio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // UNIVERSUM_H

==> pierogi_1.1.40.tar.gz: pierogi-1.1.40/keysets/universum.h <==
//
// universum.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef UNIVERSUM_H
#define UNIVERSUM_H

#include "pirkeysetmetadata.h"

class QObject;
class QComboBox;

class UniversumVCR1: public PIRKeysetMetaData
{
public:
  UniversumVCR1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumVCR2: public PIRKeysetMetaData
{
public:
  UniversumVCR2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumVCR3: public PIRKeysetMetaData
{
public:
  UniversumVCR3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumTV1: public PIRKeysetMetaData
{
public:
  UniversumTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumTV1a: public UniversumTV1
{
public:
  UniversumTV1a(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class UniversumSat1: public PIRKeysetMetaData
{
public:
  UniversumSat1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class UniversumAudio1: public PIRKeysetMetaData
{
public:
  UniversumAudio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

#endif // UNIVERSUM_H
